@@ -1,4 +1,4 @@
-from cloudipsp.configuration import __version__, __api_url__
+from cloudipsp.configuration import __api_url__
 from cloudipsp.api import Api
 from cloudipsp.checkout import Checkout
 from cloudipsp.order import Order
